/*************************************************************************/
/*                                                                       */
/*   Program Name :  m5btime                                             */
/*                                                                       */
/*     M5btime monitors header of Mark-5B format file                    */
/*                                                                       */
/*     Enviroment variables                                              */
/*           M5DIR      ---   default directory for Mark5 data           */
/*                                                                       */
/*      Version:  0.01  2010-07-21                                       */
/*                                                                       */
/*  copyright (c) 2010-   T.Kondo/NICT All Right Reserved                */
/*                                                                       */
/*************************************************************************/
/*

  Mark-5 data sync block monitor

          T.Kondo 2010.07.21 start development
                 

    m5time mk5b_filename [options]
    
     where   mk5b_filename -- Mark 5B data file name
              options (any order)
               -n nkai -- # of frames (or seconds) to display (read)
                            0 means all (default 20)

               -s nbyte   -- skip first nbyte
               -m mode  -- display mode 0|1|2|[3] for each frame display
                            10|11|12|13  for every sec display
                    
*/
#define PROGRAM_VERSION "m5btime (Ver 0.01  2010-07-21)"


#include "libk5.h"      // common header for IP-VLBI utilities 

#include "libmk5tok5.h"  // library for Mark5 to K5 conversion
#include "libvssp32.h"  // library for Mark5 to K5 conversion

/* environment variable for Mark5 data default directory set */
#define M5DIR "M5DIR" // the environment variable for Mark5 data default directory


void param_get_m5btime(int argc, char *argv[],
               char *mk5name, int *nkai, int *sbyte, int *mode)
{
    int n;
    char cbuf[80];
    //1st param should be mark5 name
    if (argc>=2){
       strcpy(mk5name,*(argv+1));
    } else {
       mk5name[0]='\0';
    }

    /* check Mark5 file name is acompanied by directory or not */
    get_true_path(mk5name, M5DIR, "./",cbuf);
    strcpy(mk5name,cbuf);

    // initialize parameters
    *nkai=20;
    *sbyte=0;
	*mode=3;

    n=3;
    while(n <=argc) {
        strcpy(cbuf,*(argv+n-1));

        if(strncmp(cbuf,"-n",2)==0){  // nkai
            n++;
            if(n > argc) break;
            *nkai = atoi(*(argv + n-1 ));
        }
        if(strncmp(cbuf,"-s",2)==0){  // skip nbytes
            n++;
            if(n > argc) break;
            *sbyte = atoi(*(argv + n-1 ));
        }
        if(strncmp(cbuf,"-m",2)==0){  // mode
            n++;
            if(n > argc) break;
            *mode = atoi(*(argv + n-1 ));
        }
        n++;
    }
}

void print_usage(void)
{
    //printf("m5tok5Rnp  %s\n",M5TOK5RNP_VERSION);
    printf("%s\n",PROGRAM_VERSION);
    printf("Usage: m5time mk5b_filename [options]\n");
    printf("\n");
    printf("where   mk5b_filename -- Mark5 data file name\n");
    printf("       options (any order)\n");
    printf("        -n nkai -- # of frames to display (read)\n");
    printf("                    0 means all frames (default 20)\n");
    printf("                            (default 20)\n");
    printf("        -s nbyte -- skip first nbyte\n");
    printf("                            (default 0)\n");
    printf("        -m mode  -- display mode 0|1|2|[3] for every frame display\n");
    printf("                    or 10|11|12|13 for every sec display\n");
    printf("                            (default 3)\n");
    printf("   Enviroment variables\n");
    printf("        %s    ---   default directory for Mark5 data\n",M5DIR);
    printf("\n");
}


int main(int argc, char *argv[])
{
       int iret,mode,nkai,sbyte;
       int istart[6];
       char mk5name[256];
       char program_version[60];
	   double fbps;      // for Mark5B
	   int iuid,tvgflag; // for Mark5B
       int framsec; // frames/sec
       double tframe,dlength;
       int64_t fsize;
      // IPBOARD_T ipb;
       //mk5_data_t mk5;    // to suport 2 bit sampling 4 ch and fanout 4 conversion

       if(argc == 1 || (argc == 2 && strncmp(*(argv+1),"--help",6)==0 )){ // 2008-02-19
          print_usage();
          exit(0);
       }
       if(argc == 2 && strncmp(*(argv+1),"--ver",5)==0 ){ // 2008-02-19
          printf("\n");
          printf("%s\n",PROGRAM_VERSION);
          printf("\n");
          exit(0);
       } 
       if (argc>=2){
          if(strncmp(*(argv+1),"env",3)==0){
          printf("   Enviroment variables\n");
          printf("        %s ---   default directory for Mark5 data\n",M5DIR);
          printf("                      ( %s )\n",getenv(M5DIR));
          printf("\n");
          exit(0);
          }
       }

       strcpy(program_version,PROGRAM_VERSION);

       /* Program Name Display */
       printf("****************************************************\n");
       printf("*    Mark-5B data time monitor                     *\n");
       printf("*      %s              *\n",PROGRAM_VERSION);
       printf("*          Kashima Space Research Center/NICT      *\n");
       printf("****************************************************\n");
       printf("\n");

       /* run parameter get */
       param_get_m5btime(argc, argv, mk5name, &nkai, &sbyte, &mode);


       //iret=mk5b_dat_anal(mk5name, 2, 10, istart,&iuid,&tvgflag,&fbps);
       iret=mk5b_dat_anal(mk5name, mode, nkai, istart,&iuid,&tvgflag,&fbps,&framsec,&fsize,&tframe,&dlength);

	   if(iret == 1){  // this is Mark5B format
		   printf("\n");
		   printf("**************** SUMMARY of DATA FORMAT ANALYSIS****************\n");
		   printf(" File Name   : %s\n",mk5name);
		   printf(" Data Format : Mark-5B\n");
           printf(" File Size   : %ld bytes",fsize);       
           printf("    Total # of Frames: %f\n",tframe);  // int64 type variable and other typ in 1 line
                                                           // results in 0 value for 2nd one in WIN32
                                                           // So, seprated in 2 lines
		   printf(" 1st Header Information\n");
		   printf("   Time (MJD HH:MM:SS.SSSS) : %03d %02d:%02d:%02d.%04d\n",
			   istart[1],istart[2],istart[3],istart[4],istart[5]);
		   printf("   User Specified (16 bits) : %04X\n",(unsigned short int)iuid);
		   printf("   TVG data flag            : %d\n",tvgflag);
		   printf(" Data Rate (Mbps) : %6.1f\n",fbps/1.0e6);
           printf(" Frames/sec       : %d\n",framsec);       
           printf(" Data Length (sec): %f\n",dlength);       
           printf("****************************************************************\n");
		   exit(0);
       } else {

	      printf("  ==> Not Mark5B format\n");
       }

       return 0;
       
}
